@@ -63,7 +63,7 @@ void flb_test_filter_parser_extract_fields()
 
     /* Parser */
     parser = flb_parser_create("dummy_test", "regex", "^(?<INT>[^ ]+) (?<FLOAT>[^ ]+) (?<BOOL>[^ ]+) (?<STRING>.+)$",
-                               NULL, NULL, NULL, MK_FALSE, NULL, 0,
+                               NULL, NULL, NULL, MK_FALSE, MK_TRUE, NULL, 0,
                                NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
@@ -148,7 +148,7 @@ void flb_test_filter_parser_reserve_data_off()
 
     /* Parser */
     parser = flb_parser_create("dummy_test", "regex", "^(?<INT>[^ ]+) (?<FLOAT>[^ ]+) (?<BOOL>[^ ]+) (?<STRING>.+)$",
-                               NULL, NULL, NULL, MK_FALSE, NULL, 0,
+                               NULL, NULL, NULL, MK_FALSE, MK_TRUE, NULL, 0,
                                NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
@@ -224,7 +224,7 @@ void flb_test_filter_parser_handle_time_key()
     /* Parser */
     parser = flb_parser_create("timestamp", "regex", "^(?<time>.*)$", "%Y-%m-%dT%H:%M:%S.%L",
                                "time",
-                               NULL, MK_FALSE,
+                               NULL, MK_FALSE, MK_TRUE,
                                NULL, 0, NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
@@ -300,7 +300,7 @@ void flb_test_filter_parser_handle_time_key_with_fractional_timestamp()
     /* Parser */
     parser = flb_parser_create("timestamp", "regex", "^(?<time>.*)$", "%s.%L",
                                "time",
-                               NULL, MK_FALSE,
+                               NULL, MK_FALSE, MK_TRUE,
                                NULL, 0, NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
@@ -380,7 +380,7 @@ void flb_test_filter_parser_ignore_malformed_time()
     /* Parser */
     parser = flb_parser_create("timestamp", "regex",
                                "^(?<time>.*)$", "%Y-%m-%dT%H:%M:%S.%L", "time",
-                               NULL, FLB_FALSE,
+                               NULL, FLB_FALSE, MK_TRUE,
                                NULL, 0, NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
@@ -456,7 +456,7 @@ void flb_test_filter_parser_preserve_original_field()
 
     /* Parser */
     parser = flb_parser_create("dummy_test", "regex", "^(?<INT>[^ ]+) (?<FLOAT>[^ ]+) (?<BOOL>[^ ]+) (?<STRING>.+)$",
-                               NULL, NULL, NULL, MK_FALSE, NULL, 0,
+                               NULL, NULL, NULL, MK_FALSE, MK_TRUE, NULL, 0,
                                NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
@@ -539,13 +539,13 @@ void flb_test_filter_parser_first_matched_when_mutilple_parser()
 
     /* Parser */
     parser = flb_parser_create("one", "regex", "^(?<one>.+?)$",
-                               NULL, NULL, NULL, MK_FALSE, NULL, 0,
-                               NULL, ctx->config);
+                               NULL, NULL, NULL, MK_FALSE, MK_TRUE,
+                               NULL, 0, NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
     parser = flb_parser_create("two", "regex", "^(?<two>.+?)$",
-                               NULL, NULL, NULL, MK_FALSE, NULL, 0,
-                               NULL, ctx->config);
+                               NULL, NULL, NULL, MK_FALSE, MK_TRUE,
+                               NULL, 0, NULL, ctx->config);
     TEST_CHECK(parser != NULL);
 
     /* Filter */
